Crate eric_sdk

Crate eric_sdk 

Structs

Eric
A structure to manage the Eric instance from the shared C library.
EricApiPayload
Shared payload for EricResponse and EricError returned by ERiC API calls.
EricResponse
A structure which summarizes the response from the Eric instance.
ValidationIssue
One <FehlerRegelpruefung> entry from ERiC validation XML.
ValidationReport
Parsed summary of ERiC validation XML.

Enums

EricError
ErrorCode
Represents the available error codes.