pub struct EricResponse {
pub payload: EricApiPayload,
}Expand description
A structure which summarizes the response from the Eric instance.
Usually returned payload can be ignored when the API call was successful and looks like this:
<?xml version="1.0" encoding="UTF-8"?>
<EricBearbeiteVorgang xmlns="http://www.elster.de/EricXML/1.1/EricBearbeiteVorgang">
<Erfolg/>
</EricBearbeiteVorgang>Fields
payload: EricApiPayloadXML payload returned by ERiC.
Implementations
Sourceimpl EricResponse
impl EricResponse
pub fn new(payload: EricApiPayload) -> Self
pub fn validation_response(&self) -> &str
pub fn server_response(&self) -> &str