Structs
- Eric
- A structure to manage the Eric instance from the shared C library.
- Eric
ApiPayload - Shared payload for
EricResponseandEricErrorreturned by ERiC API calls. - Eric
Response - A structure which summarizes the response from the Eric instance.
- Validation
Issue - One
<FehlerRegelpruefung>entry from ERiC validation XML. - Validation
Report - Parsed summary of ERiC validation XML.